@@ -6,6 +6,26 @@ files
 .. currentmodule:: compas.files
 
 
+DXF
+===
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+The DXF readers and writers are not available yet.
+
+
+LAS
+===
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+The LAS readers and writers are not available yet.
+
+
 OBJ
 ===
 
@@ -16,6 +36,20 @@ OBJ
     OBJ
     OBJReader
     OBJParser
+    OBJWriter
+
+
+OFF
+===
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    OFF
+    OFFReader
+    OFFWriter
+
 
 PLY
 ===
@@ -27,6 +61,8 @@ PLY
     PLY
     PLYReader
     PLYParser
+    PLYWriter
+
 
 STL
 ===
@@ -38,6 +74,8 @@ STL
     STL
     STLReader
     STLParser
+    STLWriter
+
 
 URDF
 ====
@@ -49,6 +87,7 @@ URDF
     URDF
     URDFParser
 
+
 XML
 ===
 
@@ -59,6 +98,7 @@ XML
     XML
     XMLReader
 
+
 GLTF
 ====
 
@@ -79,7 +119,6 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from .amf import *  # noqa: F401 F403
 from .dxf import *  # noqa: F401 F403
 from .gltf import *  # noqa: F401 F403
 from .las import *  # noqa: F401 F403
@@ -88,6 +127,6 @@ from .off import *  # noqa: F401 F403
 from .ply import *  # noqa: F401 F403
 from .stl import *  # noqa: F401 F403
 from .urdf import *  # noqa: F401 F403
-from .xml_ import *  # noqa: F401 F403
+from .xml import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
